import{d as m,b as n,ev as _,ex as v,e as A,eD as i,v as w,eA as B,a as C,u as e,c as l,bg as L,w as a,f as r,ar as u,bG as b,cE as y,cA as U,eN as x,eC as D,f4 as I,aD as V}from"./outputWidgets.3c3deba7.js";import{u as k}from"./index.1868f41b.js";import{a as E}from"./asyncComputed.41e37f4b.js";import{A as R,B as S,a as $,c as P}from"./index.9a533a9a.js";import{A as T}from"./Text.9ff37267.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[t]="e31b6117-c732-427f-8455-fc8f04f7cfc7",s._sentryDebugIdIdentifier="sentry-dbid-e31b6117-c732-427f-8455-fc8f04f7cfc7")}catch{}})();const j={class:"logo"},F=["src"],G=m({__name:"Logo",props:{brandName:{},logoUrl:{}},setup(s){const c=`${s.brandName} logo`;return(o,d)=>(n(),_("div",j,[o.logoUrl?(n(),_("img",{key:0,class:"logo-img",src:o.logoUrl,alt:c},null,8,F)):v("",!0),A("span",null,i(o.brandName),1)]))}});const H=w(G,[["__scopeId","data-v-b39249e9"]]),M=m({__name:"LoginBlock",setup(s){function t(f){const g=f.split("@")[0];return x.exports.kebabCase(g).toUpperCase().split("-").slice(0,2).map(p=>p[0]).join("")}const c=B(),{result:o,loading:d,refetch:h}=E(async()=>k.getUser());function N(){k.removeUser(),h(),c.push({name:"playerLogin"})}return(f,g)=>{const p=C("router-link");return e(d)?(n(),l(e(L),{key:0})):e(o)?(n(),l(e(U),{key:1,placement:"bottomRight"},{content:a(()=>[r(e(y),{direction:"vertical"},{default:a(()=>[r(e(T),null,{default:a(()=>[u(i(e(o).claims.email),1)]),_:1}),r(e(b),{onClick:N},{default:a(()=>[u("Logout")]),_:1})]),_:1})]),default:a(()=>[r(e(y),{align:"center",style:{cursor:"pointer"}},{default:a(()=>[r(e(R),null,{default:a(()=>[u(i(t(e(o).claims.email)),1)]),_:1})]),_:1})]),_:1})):(n(),l(e(b),{key:2},{default:a(()=>[r(p,{to:"/_player/login"},{default:a(()=>[u("Login")]),_:1})]),_:1}))}}}),Q=m({__name:"Navbar",props:{brandName:{},logoUrl:{},breadcrumb:{}},setup(s){return(t,c)=>(n(),l(e(P),{style:{padding:"5px 25px",width:"100vw"}},{breadcrumb:a(()=>[t.breadcrumb?(n(),l(e(S),{key:0},{default:a(()=>[(n(!0),_(V,null,D(t.breadcrumb,(o,d)=>(n(),l(e($),{key:d},{default:a(()=>[r(e(I),{to:o.path},{default:a(()=>[u(i(o.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):v("",!0)]),title:a(()=>[r(H,{"brand-name":t.brandName,"logo-url":t.logoUrl},null,8,["brand-name","logo-url"])]),extra:a(()=>[r(M)]),_:1}))}});export{Q as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.41843376.js.map
