import{K as n,L as p}from"./repository.681f2b72.js";import{E as s}from"./repository.d491c32b.js";import{d as a,b as m,c as f,u as e}from"./outputWidgets.3c3deba7.js";import{l as c}from"./index.1868f41b.js";import"./asyncComputed.41e37f4b.js";import"./api.046dfddf.js";import"./index.cf4c23b9.js";import"./icons.c5a369ef.js";import"./ant-design.a4c10239.js";import"./index.a5f4fbb0.js";import"./Modal.ace70b58.js";import"./Text.9ff37267.js";import"./Base.c0a62eaa.js";import"./Typography.828881b4.js";import"./index.0dfb6f48.js";import"./Link.009ce531.js";import"./Paragraph.d0a77c93.js";import"./Title.ee2bfa7b.js";import"./index.c3c37865.js";import"./index.66ff16a7.js";import"./index.a4d94226.js";import"./index.c42a2918.js";import"./CollapsePanel.f6735562.js";import"./Timeline.1ea68c65.js";import"./index.9c0f1ee5.js";import"./index.071c40f7.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.01f5bffb.js";import"./workspaces.3c7e2f6c.js";import"./runnerData.f4df2a42.js";import"./url.89508003.js";import"./record.e2163ce9.js";import"./pubsub.59f66cb7.js";import"./scripts.fb64a0b0.js";import"./envVars.7d9f90ff.js";import"./index.2091f9c4.js";import"./Form.21b032af.js";import"./hasIn.26cab181.js";import"./ExpandOutlined.8911d924.js";import"./Card.75d8d5d0.js";import"./TabPane.6a76387e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="ce748f8b-2bf6-40e3-8fbb-1557d010490d",t._sentryDebugIdIdentifier="sentry-dbid-ce748f8b-2bf6-40e3-8fbb-1557d010490d")}catch{}})();class d{constructor(o=c){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const ro=a({__name:"WorkflowKanban",setup(t){const o=new s,r=new d,i=new p("kanban");return(b,u)=>(m(),f(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{ro as default};
//# sourceMappingURL=WorkflowKanban.b4755153.js.map
