import{eQ as t,eR as r}from"./outputWidgets.3c3deba7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="4a667f4e-8760-4be5-8026-987ce3330ccd",e._sentryDebugIdIdentifier="sentry-dbid-4a667f4e-8760-4be5-8026-987ce3330ccd")}catch{}})();function s(e,n){return t(1,arguments),r(e,Date.now(),n)}export{s as f};
//# sourceMappingURL=index.a4d94226.js.map
