import"./outputWidgets.3c3deba7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="28b7202a-6613-41c3-af06-5153e9e2513b",e._sentryDebugIdIdentifier="sentry-dbid-28b7202a-6613-41c3-af06-5153e9e2513b")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.89508003.js.map
