import{B as s}from"./Base.c0a62eaa.js";import{A as t}from"./Link.009ce531.js";import{A as o}from"./Paragraph.d0a77c93.js";import{A as r}from"./Text.9ff37267.js";import{A as i}from"./Title.ee2bfa7b.js";import{T as e}from"./Typography.828881b4.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[n]="4fa50e8d-9302-4a47-a18b-321042aa5c83",a._sentryDebugIdIdentifier="sentry-dbid-4fa50e8d-9302-4a47-a18b-321042aa5c83")}catch{}})();e.Text=r;e.Title=i;e.Paragraph=o;e.Link=t;e.Base=s;e.install=function(a){return a.component(e.name,e),a.component(e.Text.displayName,r),a.component(e.Title.displayName,i),a.component(e.Paragraph.displayName,o),a.component(e.Link.displayName,t),a};
//# sourceMappingURL=index.0dfb6f48.js.map
