import{cy as n}from"./outputWidgets.3c3deba7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="83827a0a-7c5c-4ccb-a3ca-d0f2089bb11a",e._sentryDebugIdIdentifier="sentry-dbid-83827a0a-7c5c-4ccb-a3ca-d0f2089bb11a")}catch{}})();const t=(e,r)=>{n.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.032fe7c1.js.map
