import{d as f,eB as m,u as e,b as d,c as u,ev as y,f as a,w as o,bg as _,ar as p,ex as g,e as b,eD as x}from"./outputWidgets.3c3deba7.js";import"./router.2687a12c.js";import"./index.79fda194.js";import{O as w}from"./organization.aba66f3b.js";import{a as k}from"./asyncComputed.41e37f4b.js";import{A}from"./Title.ee2bfa7b.js";import{A as B}from"./index.c3c37865.js";import{A as h}from"./index.9c0f1ee5.js";import{A as C}from"./Text.9ff37267.js";import{C as D}from"./Card.75d8d5d0.js";import"./Form.21b032af.js";import"./hasIn.26cab181.js";import"./index.cf4c23b9.js";import"./record.e2163ce9.js";import"./pubsub.59f66cb7.js";import"./Base.c0a62eaa.js";import"./Typography.828881b4.js";import"./TabPane.6a76387e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="acacb441-53a7-463d-a3a3-d36645fd76a5",t._sentryDebugIdIdentifier="sentry-dbid-acacb441-53a7-463d-a3a3-d36645fd76a5")}catch{}})();const I={key:1},v={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},W=f({__name:"Billing",setup(t){const n=m().params.organizationId,{loading:l,result:c}=k(()=>w.get(n));return(z,N)=>e(l)?(d(),u(e(_),{key:0})):(d(),y("div",I,[a(e(B),{justify:"space-between",align:"center"},{default:o(()=>[a(e(A),{level:3},{default:o(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),a(e(h),{style:{"margin-top":"0"}}),a(e(D),{style:{width:"300px"}},{default:o(()=>{var i,s;return[a(e(C),{type:"secondary"},{default:o(()=>[p("Plan")]),_:1}),b("div",v,x((s=(i=e(c))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{W as default};
//# sourceMappingURL=Billing.b287aca7.js.map
