import{v as t,b as s,ev as c}from"./outputWidgets.3c3deba7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="83b07c3b-4386-4c4c-bf81-b32cda23a497",e._sentryDebugIdIdentifier="sentry-dbid-83b07c3b-4386-4c4c-bf81-b32cda23a497")}catch{}})();const o={},r={class:"organization-settings"};function a(e,n){return s(),c("div",r,"Organization settings")}const f=t(o,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.6fe62ff4.js.map
