import{g as c}from"./api.31e960ac.js";import{P as m}from"./Passwordless.f1648cf2.js";import{a as p}from"./asyncComputed.41e37f4b.js";import{W as u}from"./WidgetsFrame.da59ea76.js";import{d as l,eA as f,eB as _,b as d,ev as y,e as b,u as s,c as g,w as h,ex as w,f as v,v as k}from"./outputWidgets.3c3deba7.js";import"./runnerData.f4df2a42.js";import"./url.89508003.js";import"./index.1868f41b.js";import"./pubsub.59f66cb7.js";import"./index.288cdbc6.js";import"./icons.c5a369ef.js";import"./CircularLoading.34d2123c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="48b75cd4-1506-4a54-bd4c-5541d3b440a4",e._sentryDebugIdIdentifier="sentry-dbid-48b75cd4-1506-4a54-bd4c-5541d3b440a4")}catch{}})();const x={class:"login"},I=l({__name:"Login",setup(e){const t=f(),r=_(),{result:o}=p(c),i=()=>{const{redirect:a,...n}=r.query;if(a){t.push({path:a,query:n,params:r.params});return}t.push({name:"playerKanban",query:n})};return(a,n)=>(d(),y("div",null,[b("div",x,[s(o)?(d(),g(u,{key:0,"main-color":s(o).mainColor,theme:s(o).theme,"font-family":s(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(m,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const A=k(I,[["__scopeId","data-v-33714d9d"]]);export{A as default};
//# sourceMappingURL=Login.646b2543.js.map
