import{ac as i,V as t,Q as r,f as p}from"./outputWidgets.3c3deba7.js";import{B as l,b}from"./Base.c0a62eaa.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="b33f5db4-7684-4f3c-84ef-a5bf4aea03f9",e._sentryDebugIdIdentifier="sentry-dbid-b33f5db4-7684-4f3c-84ef-a5bf4aea03f9")}catch{}})();const c=()=>t(t({},r(b(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:a,attrs:f}=s;const{ellipsis:n}=e;i();const d=t(t(t({},e),{ellipsis:n&&typeof n=="object"?r(n,["expandable","rows"]):n,component:"span"}),f);return p(l,d,a)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=c();const g=o;export{g as A};
//# sourceMappingURL=Text.9ff37267.js.map
