import{d as b,eB as f,eA as C,H as g,b as I,c as _,u as h}from"./outputWidgets.3c3deba7.js";import{b as w}from"./index.79fda194.js";import"./router.2687a12c.js";import{C as i}from"./connector.70f72bff.js";import{a as k}from"./asyncComputed.41e37f4b.js";import{I as x,i as E}from"./icons.c5a369ef.js";import{C as D}from"./CrudView.44eff915.js";import"./index.cf4c23b9.js";import"./record.e2163ce9.js";import"./pubsub.59f66cb7.js";import"./Form.21b032af.js";import"./hasIn.26cab181.js";import"./Paragraph.d0a77c93.js";import"./Base.c0a62eaa.js";import"./Typography.828881b4.js";import"./Modal.ace70b58.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.86e502f6.js";import"./url.89508003.js";import"./index.c3c37865.js";import"./Title.ee2bfa7b.js";import"./Text.9ff37267.js";import"./index.66ff16a7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="79cdb606-baa7-41a4-a16e-3b8e031fd23e",o._sentryDebugIdIdentifier="sentry-dbid-79cdb606-baa7-41a4-a16e-3b8e031fd23e")}catch{}})();const U=b({__name:"Connectors",setup(o){const r=f(),a=C(),c=r.params.projectId;async function s(e){const t=await i.create(c,e.name,e.type);a.push({name:"connectorEditor",params:{connectorId:t.id}})}const p=[{key:"name",label:"Connector name",type:"text"},{key:"type",label:"Connector type",type:Object.entries(w.schema).map(([e,t])=>({value:e,label:t.label}))}],{loading:m,result:l,refetch:d}=k(()=>i.list(c)),u=g(()=>{var e,t;return{columns:[{name:"Name"},{name:"Type"},{name:"",align:"right"}],rows:(t=(e=l.value)==null?void 0:e.map(n=>({key:n.id,cells:[{type:"link",text:n.name,to:{name:"connectorEditor",params:{connectorId:n.id}}},{type:"text",text:n.type},{type:"actions",actions:[{icon:x,label:"Edit",onClick({key:y}){a.push({name:"connectorEditor",params:{connectorId:y}})}},{icon:E,label:"Delete",dangerous:!0,async onClick(){await n.delete(),d()}}]}]})))!=null?t:[]}});return(e,t)=>(I(),_(D,{"entity-name":"connector",loading:h(m),title:"Connectors",description:"Each connector is a version of your app. You can create a new connector by deploying your app from the local editor.","empty-title":"No connectors here yet",table:u.value,fields:p,"create-button-text":"Create connector",onCreate:s},null,8,["loading","table"]))}});export{U as default};
//# sourceMappingURL=Connectors.0e1ed9ef.js.map
