import{x as D,y as h}from"./icons.c5a369ef.js";import{d as _,H as m,b as s,ev as n,e as d,aD as f,eC as S,ez as b,eD as v,v as g,G as k,u as y,ex as o,f as I,I as N,c as C,eE as R,eF as w}from"./outputWidgets.3c3deba7.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="a6ae1b8c-7c62-4cda-8b58-fb847081d73c",a._sentryDebugIdIdentifier="sentry-dbid-a6ae1b8c-7c62-4cda-8b58-fb847081d73c")}catch{}})();const $={class:"sidebar-content"},B={class:"section"},E=["onClick"],P={class:"item-title"},U=_({__name:"Sidebar",props:{runnerData:{},displaySidebar:{type:Boolean},forceResponsivity:{}},emits:["selectRuntime","closeSidebar"],setup(a,{emit:r}){const t=a,u=e=>{p(e.id)||r("selectRuntime",e)},l=m(()=>t.runnerData.sidebar.filter(e=>e.visible)),p=e=>"id"in t.runnerData?t.runnerData.id===e:!1;return(e,i)=>(s(),n("div",{class:b(["sidebar",e.forceResponsivity,{open:e.displaySidebar}])},[d("div",$,[d("div",B,[(s(!0),n(f,null,S(l.value,c=>(s(),n("div",{key:c.id,class:b(["item",{active:p(c.id)}]),onClick:K=>u(c)},[d("div",P,v(c.name),1)],10,E))),128))])])],2))}});const V=g(U,[["__scopeId","data-v-574075ab"]]),z=a=>(R("data-v-794300d2"),a=a(),w(),a),F={class:"left-side"},G=["d"],H={key:1,class:"brand"},L=["src"],j={key:1,class:"brand-name"},q=z(()=>d("div",null,null,-1)),A={key:0,class:"signed-email"},J=_({__name:"PlayerNavbar",props:{runnerData:{},userEmail:{},forceResponsivity:{},hideSidebar:{type:Boolean}},emits:["logout","navigate"],setup(a,{emit:r}){const t=a,u=k({displaySidebar:!1}),l=m(()=>{const e=t.runnerData.sidebar;return!e||e.length==0||t.hideSidebar?!1:e.some(i=>i.visible)}),p=e=>r("navigate",e);return(e,i)=>(s(),n(f,null,[l.value||e.runnerData.logoUrl||e.runnerData.brandName||e.userEmail?(s(),n("div",{key:0,class:b(["navbar",l.value&&"background"])},[d("div",F,[l.value?(s(),n("svg",{key:0,class:b(["sidebar-menu-icon",e.forceResponsivity]),viewBox:"0 0 24 24",fill:"var(--color-main)",onClick:i[0]||(i[0]=c=>u.displaySidebar=!u.displaySidebar)},[d("path",{d:y(D)},null,8,G)],2)):o("",!0),e.runnerData.logoUrl||e.runnerData.brandName?(s(),n("div",H,[e.runnerData.logoUrl?(s(),n("img",{key:0,src:e.runnerData.logoUrl,class:"logo-image"},null,8,L)):o("",!0),e.runnerData.brandName?(s(),n("p",j,v(e.runnerData.brandName),1)):o("",!0)])):o("",!0)]),q,e.userEmail?(s(),n("div",A,[d("span",null,v(e.userEmail),1),I(N,{width:"20",height:"20",class:"logout",path:y(h),fill:"var(--color-main)",onClick:i[1]||(i[1]=c=>r("logout"))},null,8,["path"])])):o("",!0)],2)):o("",!0),l.value?(s(),C(V,{key:1,"runner-data":e.runnerData,"display-sidebar":u.displaySidebar,"force-responsivity":e.forceResponsivity,onSelectRuntime:p},null,8,["runner-data","display-sidebar","force-responsivity"])):o("",!0)],64))}});const Q=g(J,[["__scopeId","data-v-794300d2"]]);export{Q as P};
//# sourceMappingURL=PlayerNavbar.5c4ccf24.js.map
