import"./outputWidgets.3c3deba7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="2c913a3a-d8f6-4322-91fe-7d8cd2be5dd1",e._sentryDebugIdIdentifier="sentry-dbid-2c913a3a-d8f6-4322-91fe-7d8cd2be5dd1")}catch{}})();function i(e){return e.charAt(0).toUpperCase()+e.slice(1)}function l(e,a,n=!1,t=!0){const c=(t?e.toLocaleLowerCase():e).normalize("NFD").replace(/[\u0300-\u036f]/g,"").replace(/[^a-zA-Z0-9]/g,"_"),s=n?c:c.replace(/_+/g,"_");return a?s:s.replace(/_$/,"")}function u(e){var o;const n=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),t=/[a-z0-9]+/g,r=n.match(t);return(o=r==null?void 0:r.join("-"))!=null?o:""}function f(e){try{return{valid:!0,parsed:JSON.parse(e)}}catch(a){return{valid:!1,message:a.message}}}export{u as a,i as c,l as n,f as v};
//# sourceMappingURL=string.dc95a94c.js.map
