import{r,w as a}from"./runnerData.f4df2a42.js";import"./outputWidgets.3c3deba7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e2a4a4e4-5932-4198-a333-c8662e4e5c2e",e._sentryDebugIdIdentifier="sentry-dbid-e2a4a4e4-5932-4198-a333-c8662e4e5c2e")}catch{}})();async function u(e){const t=await fetch(`/_pages/${e}`);if(t.status==404)return null;if(!t.ok)throw new Error(await t.text());const{form:n}=await t.json();return n?r(n):null}async function c(){const e=await fetch("/_workspace");if(e.status!=200)return a({});const t=await e.json();return a(t)}export{u as f,c as g};
//# sourceMappingURL=api.31e960ac.js.map
