import{F as t}from"./Form.21b032af.js";import{b2 as r,cn as n}from"./outputWidgets.3c3deba7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="3152eb7c-af51-4961-8871-1462e51c9336",e._sentryDebugIdIdentifier="sentry-dbid-3152eb7c-af51-4961-8871-1462e51c9336")}catch{}})();t.useInjectFormItemContext=r;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.2091f9c4.js.map
