import{S as m}from"./Sidebar.a76ff3d8.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.a6eee27d.js";import{M as c,N as l,O as u}from"./icons.c5a369ef.js";import{d as f,eB as b,H as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.3c3deba7.js";import{a as w}from"./asyncComputed.41e37f4b.js";import"./router.2687a12c.js";import"./index.79fda194.js";import{O as z}from"./organization.aba66f3b.js";import{B as h}from"./BaseLayout.da9f9b22.js";import"./index.66ff16a7.js";import"./logo.084e5d7c.js";import"./Text.9ff37267.js";import"./Base.c0a62eaa.js";import"./Typography.828881b4.js";import"./index.9a533a9a.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Form.21b032af.js";import"./hasIn.26cab181.js";import"./index.cf4c23b9.js";import"./record.e2163ce9.js";import"./pubsub.59f66cb7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="8ffd1d8d-1a7b-4e46-a664-0edf5d64774d",o._sentryDebugIdIdentifier="sentry-dbid-8ffd1d8d-1a7b-4e46-a664-0edf5d64774d")}catch{}})();const K=f({__name:"Organization",setup(o){const n=b().params.organizationId,{result:e}=w(()=>z.get(n)),i=g(()=>e.value?[{label:"My organizations",path:"/organizations"},{label:e.value.name,path:`/organizations/${e.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:c,path:"projects"},{name:"Editors",icon:l,path:"editors"},{name:"Billing",icon:u,path:"billing"}]}];return(I,B)=>{const d=_("router-view");return y(),v(h,null,{navbar:a(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(m,{class:"sidebar",sections:s})]),content:a(()=>[r(d)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.29255a67.js.map
