import{V as s,f as p,Q as d}from"./outputWidgets.3c3deba7.js";import{B as f,b as i}from"./Base.c0a62eaa.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="00f07e81-8a59-4431-9ea5-d77fcf97b89b",e._sentryDebugIdIdentifier="sentry-dbid-00f07e81-8a59-4431-9ea5-d77fcf97b89b")}catch{}})();const y=()=>d(i(),["component"]),r=(e,a)=>{let{slots:t,attrs:o}=a;const n=s(s(s({},e),{component:"div"}),o);return p(f,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=y();const g=r;export{g as A};
//# sourceMappingURL=Paragraph.d0a77c93.js.map
