import{d,eB as b,H as m,a as f,b as g,c as v,w as s,f as i}from"./outputWidgets.3c3deba7.js";import{B as _}from"./BaseLayout.da9f9b22.js";import{a as h}from"./asyncComputed.41e37f4b.js";import"./router.2687a12c.js";import"./index.79fda194.js";import{P as y}from"./project.a7f8dc6e.js";import{O as w}from"./organization.aba66f3b.js";import{_ as z}from"./Navbar.vue_vue_type_script_setup_true_lang.a6eee27d.js";import{S as I}from"./Sidebar.a76ff3d8.js";import{e as j,R as C,S as O,T as k,U as B,v as S,H as L,V as N,W as P,N as x}from"./icons.c5a369ef.js";import"./Form.21b032af.js";import"./hasIn.26cab181.js";import"./index.cf4c23b9.js";import"./record.e2163ce9.js";import"./pubsub.59f66cb7.js";import"./logo.084e5d7c.js";import"./Text.9ff37267.js";import"./Base.c0a62eaa.js";import"./Typography.828881b4.js";import"./index.9a533a9a.js";import"./ArrowRightOutlined.08fa31dd.js";import"./index.66ff16a7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="708d9b29-8561-4a68-b057-a0eafece732f",o._sentryDebugIdIdentifier="sentry-dbid-708d9b29-8561-4a68-b057-a0eafece732f")}catch{}})();const oe=d({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=h(()=>y.get(c).then(async e=>{const t=await w.get(e.organizationId);return{project:e,organization:t}})),l=m(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=m(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:j},{name:"Builds",path:"builds",icon:C},{name:"Connectors",path:"connectors",icon:O,unavailable:!a.value.organization.featureFlags.CONNECTORS_CONSOLE},{name:"Tables",path:"tables",icon:k},{name:"API Keys",path:"api-keys",icon:B},{name:"Env Vars",path:"env-vars",icon:S},{name:"Files",path:"files",icon:L},{name:"Logs",icon:N,path:"logs"},{name:"Settings",icon:P,path:"settings"},{name:"Users",icon:x,path:"users"}]}]:[]});return(e,t)=>{const n=f("router-view");return g(),v(_,null,{content:s(()=>[i(n)]),navbar:s(()=>[i(z,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:s(()=>[i(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{oe as default};
//# sourceMappingURL=Project.ffd65695.js.map
