import{u as s}from"./index.1868f41b.js";import{d as b,b as d,ev as l,f as p,u as r}from"./outputWidgets.3c3deba7.js";import{g as c}from"./api.31e960ac.js";import{K as f,L as u}from"./repository.681f2b72.js";import{_ as g}from"./Navbar.vue_vue_type_script_setup_true_lang.41843376.js";import{a as y}from"./asyncComputed.41e37f4b.js";import{P as _}from"./repository.d491c32b.js";import"./pubsub.59f66cb7.js";import"./runnerData.f4df2a42.js";import"./url.89508003.js";import"./api.046dfddf.js";import"./index.cf4c23b9.js";import"./icons.c5a369ef.js";import"./ant-design.a4c10239.js";import"./index.a5f4fbb0.js";import"./Modal.ace70b58.js";import"./Text.9ff37267.js";import"./Base.c0a62eaa.js";import"./Typography.828881b4.js";import"./index.0dfb6f48.js";import"./Link.009ce531.js";import"./Paragraph.d0a77c93.js";import"./Title.ee2bfa7b.js";import"./index.c3c37865.js";import"./index.66ff16a7.js";import"./index.a4d94226.js";import"./index.c42a2918.js";import"./CollapsePanel.f6735562.js";import"./Timeline.1ea68c65.js";import"./index.9c0f1ee5.js";import"./index.071c40f7.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.01f5bffb.js";import"./workspaces.3c7e2f6c.js";import"./record.e2163ce9.js";import"./scripts.fb64a0b0.js";import"./envVars.7d9f90ff.js";import"./index.2091f9c4.js";import"./Form.21b032af.js";import"./hasIn.26cab181.js";import"./ExpandOutlined.8911d924.js";import"./Card.75d8d5d0.js";import"./TabPane.6a76387e.js";import"./index.9a533a9a.js";import"./ArrowRightOutlined.08fa31dd.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="645370ea-6649-4c84-b378-2e16b0cb6d2b",o._sentryDebugIdIdentifier="sentry-dbid-645370ea-6649-4c84-b378-2e16b0cb6d2b")}catch{}})();const co=b({__name:"Kanban",setup(o){const t=new _(s),i=new u("kanban"),{result:e}=y(c);return(k,w)=>{var m,a,n;return d(),l("div",null,[p(g,{"brand-name":((m=r(e))==null?void 0:m.brandName)||((a=r(e))==null?void 0:a.name),"logo-url":(n=r(e))==null?void 0:n.logoUrl},null,8,["brand-name","logo-url"]),p(f,{"kanban-repository":r(t),storage:r(i)},null,8,["kanban-repository","storage"])])}}});export{co as default};
//# sourceMappingURL=Kanban.3774aab7.js.map
