import{d as w,eA as N,eB as L,r as b,H as V,a as x,b as a,c as p,w as t,ev as l,eC as v,u as r,cw as $,aD as y,bf as E,f as o,ez as g,I as m,ar as R,eD as T,ex as k,bh as M,v as I,eE as q,eF as z,e as C}from"./outputWidgets.3c3deba7.js";import{p as F,w as H,k as P,s as W,a as j,b as G,v as J,c as K,d as O}from"./icons.c5a369ef.js";import{_ as Q}from"./logo.084e5d7c.js";import{B as U}from"./BaseLayout.da9f9b22.js";import{N as X}from"./NavbarControls.593887f6.js";import{c as Y}from"./index.9a533a9a.js";import"./workspaces.3c7e2f6c.js";import"./runnerData.f4df2a42.js";import"./url.89508003.js";import"./record.e2163ce9.js";import"./pubsub.59f66cb7.js";import"./asyncComputed.41e37f4b.js";import"./envVars.7d9f90ff.js";import"./index.1868f41b.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.3c41a322.js";import"./ant-design.a4c10239.js";import"./index.a5f4fbb0.js";import"./Modal.ace70b58.js";import"./Typography.828881b4.js";import"./Link.009ce531.js";import"./Base.c0a62eaa.js";import"./index.288cdbc6.js";import"./popupNotifcation.032fe7c1.js";import"./index.c3c37865.js";import"./Text.9ff37267.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.86e502f6.js";import"./Paragraph.d0a77c93.js";import"./ArrowRightOutlined.08fa31dd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="eff91173-89c2-4632-96f2-bc62dbb1ef95",e._sentryDebugIdIdentifier="sentry-dbid-eff91173-89c2-4632-96f2-bc62dbb1ef95")}catch{}})();const Z={key:0,class:"collapsible"},ee={key:1,class:"collapsible"},te=w({__name:"Sidebar",setup(e){var h;const n=N(),d=L(),c=b((h=d.name)!=null?h:"forms"),i=b(!1),f=()=>{i.value=!i.value},A=V(()=>[{name:"Project",children:[{name:"Stages",icon:F,path:"stages"},{name:"Workflow",icon:H,path:"workflow"},{name:"Threads",icon:P,path:"kanban"}]},{name:"Settings",children:[{name:"Style",icon:W,path:"style"},{name:"Sidebar",icon:j,path:"sidebar"},{name:"Requirements",icon:G,path:"requirements"},{name:"Env Vars",icon:J,path:"env-vars"}]}]),B=_=>{n.push(_.path),c.value=_.path};return(_,pe)=>{const D=x("router-link");return a(),p(r(M),{"inline-collapsed":i.value,style:{display:"flex","flex-direction":"column"}},{default:t(()=>[(a(!0),l(y,null,v(A.value,u=>(a(),p(r($),{key:u.name,title:u.name},{default:t(()=>[(a(!0),l(y,null,v(u.children,s=>(a(),p(r(E),{key:s.name,role:"button",tabindex:"0",onClick:de=>B(s)},{icon:t(()=>[o(m,{class:g({active:c.value===s.path}),path:s.icon,width:"18",height:"18"},null,8,["class","path"])]),default:t(()=>[o(D,{to:s.path,class:g({active:c.value===s.path})},{default:t(()=>[R(T(s.name),1)]),_:2},1032,["to","class"])]),_:2},1032,["onClick"]))),128))]),_:2},1032,["title"]))),128)),i.value?(a(),l("div",Z,[o(m,{path:r(K),onClick:f},null,8,["path"])])):k("",!0),i.value?k("",!0):(a(),l("div",ee,[o(m,{path:r(O),onClick:f},null,8,["path"])]))]),_:1},8,["inline-collapsed"])}}});const ae=I(te,[["__scopeId","data-v-faa20278"]]);const oe={},S=e=>(q("data-v-81cd596e"),e=e(),z(),e),se={class:"logo"},ne=S(()=>C("img",{src:Q,alt:"Abstra cloud logo"},null,-1)),re=S(()=>C("span",null," Abstra ",-1)),ce=[ne,re];function ie(e,n){return a(),l("div",se,ce)}const le=I(oe,[["render",ie],["__scopeId","data-v-81cd596e"]]),Fe=w({__name:"Workspace",setup(e){return(n,d)=>{const c=x("router-view");return a(),p(U,{"full-canvas":""},{navbar:t(()=>[o(r(Y),{style:{padding:"5px 25px"}},{title:t(()=>[o(le)]),extra:t(()=>[o(X,{"show-github-stars":"","show-v-s-code-button":""})]),_:1})]),sidebar:t(()=>[o(ae,{class:"sidebar"})]),content:t(()=>[o(c)]),_:1})}}});export{Fe as default};
//# sourceMappingURL=Workspace.1f6bc5f9.js.map
