import{u as I}from"./index.1868f41b.js";import{f as u,eG as D,d as w,b as o,c as l,w as c,ar as f,u as n,bG as P,v as x,eA as R,H as B,ev as b,ex as g,e as K,ew as S,bg as T,aD as V,eC as N,eD as j,I as $}from"./outputWidgets.3c3deba7.js";import{g as H}from"./api.31e960ac.js";import{a as y}from"./asyncComputed.41e37f4b.js";import{P as z}from"./PlayerNavbar.5c4ccf24.js";import{P as E}from"./repository.d491c32b.js";import{e as F}from"./icons.c5a369ef.js";import{A as G}from"./ArrowRightOutlined.08fa31dd.js";import"./index.0dfb6f48.js";import"./index.4ba284cf.js";import{A as v}from"./index.c3c37865.js";import{T as h}from"./Typography.828881b4.js";import{C as L}from"./Card.75d8d5d0.js";import"./pubsub.59f66cb7.js";import"./runnerData.f4df2a42.js";import"./url.89508003.js";import"./Base.c0a62eaa.js";import"./Link.009ce531.js";import"./Paragraph.d0a77c93.js";import"./Text.9ff37267.js";import"./Title.ee2bfa7b.js";import"./TabPane.6a76387e.js";import"./hasIn.26cab181.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="27f10f99-911e-48e5-960d-13ee510c5853",a._sentryDebugIdIdentifier="sentry-dbid-27f10f99-911e-48e5-960d-13ee510c5853")}catch{}})();function k(a){for(var e=1;e<arguments.length;e++){var t=arguments[e]!=null?Object(arguments[e]):{},r=Object.keys(t);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(t).filter(function(s){return Object.getOwnPropertyDescriptor(t,s).enumerable}))),r.forEach(function(s){M(a,s,t[s])})}return a}function M(a,e,t){return e in a?Object.defineProperty(a,e,{value:t,enumerable:!0,configurable:!0,writable:!0}):a[e]=t,a}var _=function(e,t){var r=k({},e,t.attrs);return u(D,k({},r,{icon:G}),null)};_.displayName="ArrowRightOutlined";_.inheritAttrs=!1;const W=_,q=w({__name:"KanbanButton",emits:["go-to-kanban"],setup(a,{emit:e}){return(t,r)=>(o(),l(n(P),{class:"kanban-btn",onClick:r[0]||(r[0]=s=>e("go-to-kanban"))},{default:c(()=>[f(" Kanban "),u(n(W))]),_:1}))}});const J=x(q,[["__scopeId","data-v-73dd2178"]]),Q={class:"page"},U=w({__name:"Home",setup(a){const e=R(),{result:t,loading:r}=y(H),s=B(()=>{var i,d;return(d=(i=t.value)==null?void 0:i.sidebar.filter(p=>p.visible))!=null?d:[]}),O=i=>{e.push({path:`/${i}`})},A=()=>{e.push({name:"playerKanban"})},C=y(async()=>{try{return await new E(I).getData({selection:[]}),!0}catch{return!1}});return(i,d)=>{var p;return o(),b("div",Q,[n(t)?(o(),l(z,{key:0,"runner-data":n(t),"hide-sidebar":""},null,8,["runner-data"])):g("",!0),K("div",{class:"container",style:S({backgroundColor:(p=n(t))==null?void 0:p.theme})},[n(r)?(o(),l(n(T),{key:0})):s.value.length===0?(o(),l(n(h),{key:1,type:"secondary",style:{"font-size":"18px"}},{default:c(()=>[f(" There are no public forms available ")]),_:1})):(o(),l(n(v),{key:2,vertical:"",gap:"large",style:{padding:"120px 0"}},{default:c(()=>[(o(!0),b(V,null,N(s.value,m=>(o(),l(n(L),{key:m.id,class:"form-card",onClick:Y=>O(m.path)},{default:c(()=>[u(n(v),{gap:"large",align:"center",justify:"space-between"},{default:c(()=>[u(n(h),{style:{"font-size":"18px","font-weight":"500"}},{default:c(()=>[f(j(m.name),1)]),_:2},1024),u($,{path:n(F),fill:"#000",width:"20"},null,8,["path"])]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1})),n(C)?(o(),l(J,{key:3,onGoToKanban:A})):g("",!0)],4)])}}});const we=x(U,[["__scopeId","data-v-68d92933"]]);export{we as default};
//# sourceMappingURL=Home.99fb1d3b.js.map
