import{C as n,A as o}from"./CollapsePanel.f6735562.js";import{T as t,A as d}from"./Timeline.1ea68c65.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[i]="07387dd4-859c-45c0-a4e7-2814935d2fd2",e._sentryDebugIdIdentifier="sentry-dbid-07387dd4-859c-45c0-a4e7-2814935d2fd2")}catch{}})();n.Panel=o;n.install=function(e){return e.component(n.name,n),e.component(o.name,o),e};t.Item=d;t.install=function(e){return e.component(t.name,t),e.component(d.name,d),e};
//# sourceMappingURL=index.c42a2918.js.map
